@@ -12,7 +12,7 @@
 #
 # The Initial Developer of the Original Code is CWI.
 # Portions created by CWI are Copyright (C) 1997-July 2008 CWI.
-# Copyright August 2008-2013 MonetDB B.V.
+# Copyright August 2008-2014 MonetDB B.V.
 # All Rights Reserved.
 
 """
@@ -23,6 +23,7 @@ import socket
 import logging
 import struct
 import hashlib
+import os
 from cStringIO import StringIO
 
 
@@ -46,6 +47,7 @@ MSG_QPREPARE = "&5"
 MSG_QBLOCK = "&6"
 MSG_HEADER = "%"
 MSG_TUPLE = "["
+MSG_TUPLE_NOSLICE = "="
 MSG_REDIRECT = "^"
 MSG_OK = "=OK"
 
@@ -77,6 +79,14 @@ class Connection(object):
         unix_socket is used if hostname is not defined.
         """
 
+        if hostname and hostname[:1] == '/' and not unix_socket:
+            unix_socket = '%s/.s.monetdb.%d' % (hostname, port)
+            hostname = None
+        if not unix_socket and os.path.exists("/tmp/.s.monetdb.%i" % port):
+            unix_socket = "/tmp/.s.monetdb.%i" % port
+        elif not hostname:
+            hostname = 'localhost'
+
         self.hostname = hostname
         self.port = port
         self.username = username
