@@ -12,7 +12,7 @@
 #
 # The Initial Developer of the Original Code is CWI.
 # Portions created by CWI are Copyright (C) 1997-July 2008 CWI.
-# Copyright August 2008-2013 MonetDB B.V.
+# Copyright August 2008-2014 MonetDB B.V.
 # All Rights Reserved.
 
 import logging
@@ -395,7 +395,10 @@ class Cursor(object):
 
             elif line.startswith(mapi.MSG_TUPLE):
                 values = self.__parse_tuple(line)
-                self.__rows .append(values)
+                self.__rows.append(values)
+
+            elif line.startswith(mapi.MSG_TUPLE_NOSLICE):
+                self.__rows.append((line[1:],))
 
             elif line.startswith(mapi.MSG_QBLOCK):
                 self.__rows = []
@@ -423,7 +426,7 @@ class Cursor(object):
                 self.description = None
                 self.rowcount = -1
 
-            elif line.startswith(mapi.MSG_PROMPT):
+            elif line == mapi.MSG_PROMPT:
                 return
 
             elif line.startswith(mapi.MSG_ERROR):
